@@ -11,37 +11,17 @@
 #
 ###############################################################
 
-import web
+#pylint: disable=redefined-builtin
+
+
 import shutil
-import codecs
+import io
 import os
-from clam.common.data import CLAMMetaData, CLAMOutputFile
+import flask
+from clam.common.data import CLAMMetaData, CLAMOutputFile, AbstractConverter
+from clam.common.util import withheaders
 import clam.common.formats
 
-class AbstractConverter(object):
-    acceptforinput = [] #List of formats; accept the following formats as target for conversion of input
-    acceptforoutput = [] #List of formats; accept the following formats as source for conversion for output
-
-    label = "(ERROR: label not overriden from AbstractConverter!)" #Override this with a sensible name
-
-    def __init__(self, id, **kwargs):
-        if 'label' in kwargs:
-            self.id = id
-            self.label = kwargs['label']
-
-    def convertforinput(self,filepath, metadata):
-        """Convert from target format into one of the source formats. Relevant if converters are used in InputTemplates. Metadata already is metadata for the to-be-generated file. 'filepath' is both the source and the target file, the source file will be erased and overwritten with the conversion result!"""
-        assert isinstance(metadata, CLAMMetaData) #metadata of the destination file (file to be generated here)
-        if not metadata.__class__ in self.acceptforinput:
-            raise Exception("Convertor " + self.__class__.__name__ + " can not convert input files to " + metadata.__class__.__name__ + "!")
-        return False #Return True on success, False on failure
-
-    def convertforoutput(self,outputfile):
-        """Convert from one of the source formats into target format. Relevant if converters are used in OutputTemplates. Sourcefile is a CLAMOutputFile instance."""
-        assert isinstance(outputfile, CLAMOutputFile) #metadata of the destination file (file to be generated here)
-        if not outputfile.metadata.__class__ in self.acceptforoutput:
-            raise Exception("Convertor " + self.__class__.__name__ + " can not convert input files to " + outputfile.metadata.__class__.__name__ + "!")
-        return [] #Return converted contents (must be an iterable) or raise an exception on error
 
 class CharEncodingConverter(AbstractConverter):
     acceptforinput = acceptforoutput = [clam.common.formats.PlainTextFormat]
@@ -49,7 +29,7 @@ class CharEncodingConverter(AbstractConverter):
     label = "CharEncodingConverter" #to be overriden in instance creation
 
     def __init__(self, id,  **kwargs):
-        if not 'label' in kwargs:
+        if 'label' not in kwargs:
             raise Exception("No label specified for EncodingConvertor!")
 
         if 'fromcharset' in kwargs:
@@ -70,8 +50,8 @@ class CharEncodingConverter(AbstractConverter):
         shutil.copy(filepath, filepath + '.convertsource')
 
         try:
-            fsource = codecs.open(filepath + '.convertsource','r',self.charset)
-            ftarget = codecs.open(filepath,'w',metadata['encoding'])
+            fsource = io.open(filepath + '.convertsource','r',encoding=self.charset)
+            ftarget = io.open(filepath,'w',encoding=metadata['encoding'])
             for line in fsource:
                 ftarget.write(line + "\n")
             success = True
@@ -89,9 +69,7 @@ class CharEncodingConverter(AbstractConverter):
         """Convert from one of the source formats into target format. Relevant if converters are used in OutputTemplates. Outputfile is a CLAMOutputFile instance."""
         super(CharEncodingConverter,self).convertforoutput(outputfile)
 
-        web.header('Content-Type', 'text/plain; charset=' + self.charset)
-        for line in outputfile:
-            yield line.encode(self.charset)
+        return withheaders( flask.make_response( ( line.encode(self.charset) for line in outputfile ) ) , 'text/plain; charset=' + self.charset)
 
 
 
@@ -111,7 +89,7 @@ class PDFtoTextConverter(AbstractConverter):
         returncode = os.system(self.converttool + ' -layout ' + filepath + '.convertsource.pdf ' + filepath)
         os.unlink(filepath + '.convertsource.pdf')
 
-        return (returncode == 0)
+        return returncode == 0
 
 
 class PDFtoHTMLConverter(AbstractConverter):
@@ -130,7 +108,7 @@ class PDFtoHTMLConverter(AbstractConverter):
         returncode = os.system(self.converttool + ' -layout ' + filepath + '.convertsource.pdf ' + filepath)
         os.unlink(filepath + '.convertsource.pdf')
 
-        return (returncode == 0)
+        return returncode == 0
 
 
 class MSWordConverter(AbstractConverter):
@@ -149,5 +127,5 @@ class MSWordConverter(AbstractConverter):
         returncode = os.system(self.converttool + ' -x ' + filepath + '.convertsource.doc > ' + filepath)
         os.unlink(filepath + '.convertsource.doc')
 
-        return (returncode == 0)
+        return returncode == 0
 
