@@ -1,28 +1,28 @@
 ###############################################################
 # CLAM: Computational Linguistics Application Mediator
-# -- Parameter classes --
+# -- CLAM Parameter Classes --
 #       by Maarten van Gompel (proycon)
-#       http://ilk.uvt.nl/clam
-#       http://ilk.uvt.nl/~mvgompel
-#       Induction for Linguistic Knowledge Research Group
-#       Universiteit van Tilburg
+#       https://proycon.github.io/clam
+#
+#       Centre for Language and Speech Technology / Language Machines
+#       Radboud University Nijmegen
 #
 #       Licensed under GPLv3
 #
 ###############################################################
 
+#pylint: disable=redefined-builtin
+
+
+import sys
 from lxml import etree as ElementTree
-from StringIO import StringIO
+from io import StringIO #pylint: disable=wrong-import-order
 from clam.common.util import xmlescape
 
 class AbstractParameter(object):
     """This is the base class from which all parameter classes have to be derived."""
 
-
-
     def __init__(self, id, name, description = '', **kwargs):
-
-
         #: A unique alphanumeric ID
         self.id = id
 
@@ -44,6 +44,8 @@ class AbstractParameter(object):
         self.nospace = False
         self.require = []
         self.forbid = []
+        self.validator = None
+        self.default = None #None is a viable default for ALL parameter types because None means that the parameter is unset, so do not set this to False, 0, "" or 0.0 or something, only the user may do that with a default= parameter.
 
         #: You can restrict this parameter to only be available to certain users, set the usernames you want to allow here, all others are denied
         self.allowusers = []
@@ -56,8 +58,11 @@ class AbstractParameter(object):
                 self.allowusers = value  #Users to allow access to this parameter (If not set, all users have access)
             elif key == 'denyusers':
                 self.denyusers = value   #Users to deny access to this parameter (If not set, nobody is denied)
-            elif key == 'value' or key == 'default':
-                #set an error message
+            elif key == 'default':
+                if 'value' not in kwargs:
+                    if self.set(value):
+                        self.default = value
+            elif key == 'value':
                 self.set(value)
             elif key == 'required':
                 self.required = value  #Mandatory parameter?
@@ -75,6 +80,8 @@ class AbstractParameter(object):
                 self.error = value
             elif key == 'flag' or key == 'option' or key == 'paramflag':
                 self.paramflag = value
+            elif key == 'validator':
+                self.validator = value
             else:
                 raise Exception("Unknown attribute specified for parameter: " + key + "=" + str(value))
 
@@ -84,8 +91,25 @@ class AbstractParameter(object):
 
     def validate(self,value):
         """Validate the parameter"""
-        self.error = None #reset error
-        return True
+        if self.validator is not None:
+            try:
+                valid = self.validator(value)
+            except Exception as e:
+                import pdb; pdb.set_trace()
+            if isinstance(valid, tuple) and len(valid) == 2:
+                valid, errormsg = valid
+            elif isinstance(valid, bool):
+                errormsg = "Invalid value"
+            else:
+                raise TypeError("Custom validator must return a boolean or a (bool, errormsg) tuple.")
+            if valid:
+                self.error = None
+            else:
+                self.error = errormsg
+            return valid
+        else:
+            self.error = None #reset error
+            return True
 
     def compilearg(self):
         """This method compiles the parameter into syntax that can be used on the shell, such as for example: --paramflag=value"""
@@ -107,17 +131,17 @@ class AbstractParameter(object):
         if self.paramflag:
             xml += ' flag="'+self.paramflag + '"'
         for key, v in self.kwargs.items():
-            if not key in ['value','error','name','description','flag','paramflag']:
+            if key not in ('value','error','name','description','flag','paramflag', 'validator'):
                 if isinstance(v, bool):
                     xml += ' ' + key + '="' + str(int(v))+ '"'
                 elif isinstance(v, list):
                     xml += ' ' + key + '="'+xmlescape(",".join(v))+ '"'
-                elif isinstance(v, unicode) or isinstance(v, str)  :
+                elif isinstance(v, str): #pylint: disable=undefined-variable
                     xml += ' ' + key + '="'+xmlescape(v)+ '"'
                 else:
                     xml += ' ' + key + '="'+xmlescape(str(v))+ '"'
         if self.hasvalue:
-            xml += ' value="'+xmlescape(unicode(self.value)) + '"'
+            xml += ' value="'+xmlescape(str(self.value)) + '"'
         if self.error:
             xml += ' error="'+xmlescape(self.error) + '"'
         xml += " />"
@@ -125,18 +149,10 @@ class AbstractParameter(object):
 
     def __str__(self):
         if self.value:
-            if isinstance(self.value, unicode):
-                return self.value.encode('utf-8')
             return str(self.value)
         else:
             return ""
 
-    def __unicode__(self):
-        if self.value:
-            return self.value
-        else:
-            return u""
-
     def __repr__(self):
         if self.error:
             error = " (ERROR: " + self.error + ")"
@@ -179,7 +195,7 @@ class AbstractParameter(object):
     @staticmethod
     def fromxml(node):
         """Create a Parameter instance (of any class derived from AbstractParameter!) given its XML description. Node can be a string containing XML or an lxml _Element"""
-        if not isinstance(node,ElementTree._Element):
+        if not isinstance(node,ElementTree._Element): #pylint: disable=protected-access
             node = ElementTree.parse(StringIO(node)).getroot()
         if node.tag in globals():
             id = ''
@@ -187,6 +203,7 @@ class AbstractParameter(object):
             name = ''
             description = ''
             kwargs = {}
+            error = None
             for attrib, value in node.attrib.items():
                 if attrib == 'id':
                     id = value
@@ -196,6 +213,8 @@ class AbstractParameter(object):
                     name = value
                 elif attrib == 'description':
                     description = value
+                elif attrib == 'error':
+                    error = value
                 else:
                     kwargs[attrib] = value
 
@@ -205,7 +224,7 @@ class AbstractParameter(object):
 
             for subtag in node: #parse possible subtags
                 if subtag.tag == 'choice': #extra parsing for choice parameter (TODO: put in a better spot)
-                    if not 'choices' in kwargs: kwargs['choices'] = {}
+                    if 'choices' not in kwargs: kwargs['choices'] = {}
                     kwargs['choices'][subtag.attrib['id']] = subtag.text
                     if 'selected' in subtag.attrib and (subtag.attrib['selected'] == '1' or subtag.attrib['selected'] == 'yes'):
                         if 'multi' in kwargs and (kwargs['multi'] == 'yes' or kwargs['multi'] == '1' or kwargs['multi'] == 'true'):
@@ -213,7 +232,10 @@ class AbstractParameter(object):
                         else:
                             kwargs['value'] = subtag.attrib['id']
 
-            return globals()[node.tag](id, name, description, **kwargs) #return parameter instance
+            parameter = globals()[node.tag](id, name, description, **kwargs) #return parameter instance
+            if error:
+                parameter.error = error #prevent error from getting reset
+            return parameter
         else:
             raise Exception("No such parameter exists: " + node.tag)
 
@@ -241,10 +263,7 @@ class BooleanParameter(AbstractParameter):
 
     def set(self, value = True):
         """Set the boolean parameter"""
-        if value is True or value == 1 or ( (isinstance(value, str) or isinstance(value, unicode)) and (value.lower() == "1" or value.lower() == "yes" or  value.lower() == "true" or value.lower() == "enabled") ):
-            value = True
-        else:
-            value = False
+        value = value in (True,1) or (isinstance(value, str) and (value.lower() in ("1","yes","true","enabled"))) #pylint: disable=undefined-variable
         return super(BooleanParameter,self).set(value)
 
     def unset(self):
@@ -261,13 +280,14 @@ class BooleanParameter(AbstractParameter):
             return ""
 
     def valuefrompostdata(self, postdata):
-        """This parameter method searches the POST data and retrieves the values it needs. It does not set the value yet though, but simply returns it. Needs to be explicitly passed to parameter.set()"""
-        if not self.id in postdata:
-            return False #False instead of None
-        elif self.id in postdata and ( (isinstance(postdata[self.id], bool) and postdata[self.id]) or postdata[self.id] == 1 or postdata[self.id] == '1'  or postdata[self.id].lower() == 'true' or postdata[self.id].lower() == 'yes' or postdata[self.id].lower() == 'enabled'):
-            return True #postdata[self.id]
+        """This parameter method searches the POST data and retrieves the values it needs. It does not set the value yet though, but simply returns it. Needs to be explicitly passed to parameter.set(). It typically returns the default None when something is left unset (but that default can be overridden)"""
+        if self.id in postdata:
+            if ( (isinstance(postdata[self.id], bool) and postdata[self.id]) or postdata[self.id] == 1 or postdata[self.id].lower() in ('true','yes','enabled','1')):
+                return True #postdata[self.id]
+            else:
+                return False
         else:
-            return False
+            return None
 
 
 class StaticParameter(AbstractParameter):
@@ -287,14 +307,15 @@ class StringParameter(AbstractParameter):
         """Keyword arguments::
 
             ``maxlength`` - The maximum length of the value, in number of characters
+            ``validator`` - A custom validator function expecting one parameter (the value) and returning either a boolean or a (boolean, errormsg) tuple.
         """
 
         self.maxlength = 0 #unlimited
 
-        for key, value in kwargs.items():
+        for key, value in list(kwargs.items()):
             if key == 'maxlength':
                 self.maxlength = int(value)
-                del kwargs[key]
+                del kwargs['maxlength']
 
         super(StringParameter,self).__init__(id,name,description, **kwargs)
 
@@ -305,7 +326,7 @@ class StringParameter(AbstractParameter):
             self.error = "Text too long, exceeding maximum of " + str(self.maxlength) + " characters allowed"
             return False
         else:
-            return True
+            return super(StringParameter,self).validate(value)
 
     def compilearg(self):
         needsquotes = False
@@ -341,10 +362,11 @@ class ChoiceParameter(AbstractParameter):
         multi   - (boolean) User may select multiple values? (parameter value will be a list)
         delimiter - The delimiter between multiple options (if multi=True), and
                     when used on the command line.
+        ``validator`` - A custom validator function expecting one parameter (the value) and returning either a boolean or a (boolean, errormsg) tuple.
         """
 
 
-        if not 'choices' in kwargs:
+        if 'choices' not in kwargs:
             raise Exception("No parameter choices specified for parameter " + id + "!")
         self.choices = [] #list of key,value tuples
         for x in kwargs['choices']:
@@ -358,13 +380,13 @@ class ChoiceParameter(AbstractParameter):
         self.delimiter = ","
         self.showall = False
         self.multi = False
-        if not 'value' in kwargs and not 'default' in kwargs and (not 'multi' in kwargs or not kwargs['multi']):
+        if  'value' not in kwargs and 'default' not in kwargs and ('multi' not in kwargs or not kwargs['multi']):
             self.value = self.choices[0][0] #no default specified, first choice is default
 
         if 'multi' in kwargs and kwargs['multi']:
             self.value = []
 
-        for key, value in kwargs.items():
+        for key, value in list(kwargs.items()):
             if key == 'multi':
                 self.multi = bool(value) #boolean
                 del kwargs[key]
@@ -388,7 +410,7 @@ class ChoiceParameter(AbstractParameter):
             if not v in [x[0] for x in self.choices]:
                 self.error = "Selected value was not an option! (" + str(v) + ")"
                 return False
-        return True
+        return super(ChoiceParameter,self).validate(values)
 
 
     def set(self, value):
@@ -438,7 +460,7 @@ class ChoiceParameter(AbstractParameter):
                 else:
                     xml += ' ' + key + '="'+xmlescape(value)+ '"'
         if self.error:
-             xml += ' error="'+self.error + '"'
+            xml += ' error="'+self.error + '"'
         xml += ">"
         for key, value in self.choices:
             if self.value == key or (isinstance(self.value ,list) and key in self.value):
@@ -458,8 +480,8 @@ class ChoiceParameter(AbstractParameter):
                 values = []
                 for choicekey in [x[0] for x in self.choices]:
                     if choicekey in passedvalues:
-                            found = True
-                            values.append(choicekey)
+                        found = True
+                        values.append(choicekey)
             else:
                 values = []
                 for choicekey in [x[0] for x in self.choices]:
@@ -503,9 +525,9 @@ class IntegerParameter(AbstractParameter):
         self.maxvalue = 0 #unlimited
 
         #defaults
-        if not 'default' in kwargs and not 'value' in kwargs:
+        if 'value' not in kwargs:
             self.value = 0
-        for key, value in kwargs.items():
+        for key, value in list(kwargs.items()):
             if key == 'minvalue' or key == 'min':
                 self.minvalue = int(value)
                 del kwargs[key]
@@ -523,13 +545,13 @@ class IntegerParameter(AbstractParameter):
         self.error = None
         try:
             value = int(value)
-        except:
+        except ValueError:
             self.error = "Not a number"
             return False
-        if self.minvalue == self.maxvalue and self.maxvalue == 0:
-            return True #no restraints
+        if self.minvalue == self.maxvalue and self.maxvalue == 0: #no restraints
+            return super(IntegerParameter,self).validate(value)
         elif (self.maxvalue < self.minvalue) or ((value >= self.minvalue) and  (value <= self.maxvalue) ) :
-            return True
+            return super(IntegerParameter,self).validate(value)
         else:
             self.error = "Number must be a whole number between " + str(self.minvalue) + " and " + str(self.maxvalue)
             return False
@@ -564,9 +586,9 @@ class FloatParameter(AbstractParameter):
 
 
         #defaults
-        if not 'default' in kwargs and not 'value' in kwargs:
+        if 'value' not in kwargs:
             self.value = 0.0
-        for key, value in kwargs.items():
+        for key, value in list(kwargs.items()):
             if key == 'minvalue' or key == 'min':
                 self.minvalue = float(value)
                 del kwargs[key]
@@ -585,13 +607,13 @@ class FloatParameter(AbstractParameter):
         self.error = None
         try:
             value = float(value)
-        except:
+        except ValueError:
             self.error = "Not a valid number"
             return False
-        if self.minvalue == self.maxvalue and self.maxvalue == 0:
-            return True #no restraints
-        elif ((self.maxvalue < self.minvalue) or ((value >= self.minvalue) and  (value <= self.maxvalue))):
-            return True
+        if self.minvalue == self.maxvalue and self.maxvalue == 0: #no restraints
+            return super(FloatParameter,self).validate(value)
+        elif (self.maxvalue < self.minvalue) or ((value >= self.minvalue) and  (value <= self.maxvalue)):
+            return super(FloatParameter,self).validate(value)
         else:
             self.error = "Number must be between " + str(self.minvalue) + " and " + str(self.maxvalue)
             return False
