@@ -1,5 +1,6 @@
-import codecs
+import io
 import time
+import sys
 
 READY = 0
 RUNNING = 1
@@ -8,7 +9,7 @@ DONE = 2
 
 def write(statusfile, statusmessage, completion = 0, timestamp = False, encoding = 'utf-8'):
     if statusfile:
-        f = codecs.open(statusfile, 'a', encoding)
+        f = io.open(statusfile, 'a', encoding=encoding)
         if not timestamp:
             timestamp = int(time.time())
         if isinstance(completion, float) and completion >= 0.0 and completion <= 1.0:
